@@ -2,6 +2,7 @@ from .bottom_up_eval import (aggregate_results, get_group_preds,
                              get_multi_stage_outputs)
 from .eval_hooks import DistEvalHook, EvalHook
 from .mesh_eval import compute_similarity_transform
+from .pose3d_eval import keypoint_mpjpe
 from .top_down_eval import (keypoint_auc, keypoint_epe, keypoint_pck_accuracy,
                             keypoints_from_heatmaps, keypoints_from_regression,
                             pose_pck_accuracy, post_dark_udp)
@@ -10,5 +11,6 @@ __all__ = [
     'EvalHook', 'DistEvalHook', 'pose_pck_accuracy', 'keypoints_from_heatmaps',
     'keypoints_from_regression', 'keypoint_pck_accuracy', 'keypoint_auc',
     'keypoint_epe', 'get_group_preds', 'get_multi_stage_outputs',
-    'aggregate_results', 'compute_similarity_transform', 'post_dark_udp'
+    'aggregate_results', 'compute_similarity_transform', 'post_dark_udp',
+    'keypoint_mpjpe'
 ]
