@@ -12,14 +12,15 @@ def _calc_distances(preds, targets, mask, normalize):
     Note:
         batch_size: N
         num_keypoints: K
+        dimension of keypoints: D (normally, D=2 or D=3)
 
     Args:
-        preds (np.ndarray[N, K, 2]): Predicted keypoint location.
-        targets (np.ndarray[N, K, 2]): Groundtruth keypoint location.
+        preds (np.ndarray[N, K, D]): Predicted keypoint location.
+        targets (np.ndarray[N, K, D]): Groundtruth keypoint location.
         mask (np.ndarray[N, K]): Visibility of the target. False for invisible
             joints, and True for visible. Invisible joints will be ignored for
             accuracy calculation.
-        normalize (np.ndarray[N, 2]): Typical value is heatmap_size
+        normalize (np.ndarray[N, D]): Typical value is heatmap_size
 
     Returns:
         np.ndarray[K, N]: The normalized distances.
@@ -202,6 +203,29 @@ def keypoint_auc(pred, gt, mask, normalize, num_step=20):
     return auc
 
 
+def keypoint_nme(pred, gt, mask, normalize_factor):
+    """Calculate the normalized mean error (NME).
+
+    Note:
+        batch_size: N
+        num_keypoints: K
+
+    Args:
+        pred (np.ndarray[N, K, 2]): Predicted keypoint location.
+        gt (np.ndarray[N, K, 2]): Groundtruth keypoint location.
+        mask (np.ndarray[N, K]): Visibility of the target. False for invisible
+            joints, and True for visible. Invisible joints will be ignored for
+            accuracy calculation.
+        normalize_factor (np.ndarray[N, 2]): Normalization factor.
+
+    Returns:
+        float: normalized mean error
+    """
+    distances = _calc_distances(pred, gt, mask, normalize_factor)
+    distance_valid = distances[distances != -1]
+    return distance_valid.sum() / max(1, len(distance_valid))
+
+
 def keypoint_epe(pred, gt, mask):
     """Calculate the end-point error.
 
@@ -219,11 +243,12 @@ def keypoint_epe(pred, gt, mask):
     Returns:
         float: Average end-point error.
     """
+
     distances = _calc_distances(
-        pred, gt, mask, np.tile(np.array([[1, 1]]), (pred.shape[0], 1)))
+        pred, gt, mask,
+        np.ones((pred.shape[0], pred.shape[2]), dtype=np.float32))
     distance_valid = distances[distances != -1]
-    valid_num = len(distance_valid)
-    return distance_valid.sum() / valid_num
+    return distance_valid.sum() / max(1, len(distance_valid))
 
 
 def _taylor(heatmap, coord):
@@ -371,6 +396,38 @@ def _gaussian_blur(heatmaps, kernel=11):
     return heatmaps
 
 
+def keypoints_from_regression(regression_preds, center, scale, img_size):
+    """Get final keypoint predictions from regression vectors and transform
+    them back to the image.
+
+    Note:
+        batch_size: N
+        num_keypoints: K
+
+    Args:
+        regression_preds (np.ndarray[N, K, 2]): model prediction.
+        center (np.ndarray[N, 2]): Center of the bounding box (x, y).
+        scale (np.ndarray[N, 2]): Scale of the bounding box
+            wrt height/width.
+        img_size (list(img_width, img_height)): model input image size.
+
+
+    Returns:
+        preds (np.ndarray[N, K, 2]): Predicted keypoint location in images.
+        maxvals (np.ndarray[N, K, 1]): Scores (confidence) of the keypoints.
+    """
+    N, K, _ = regression_preds.shape
+    preds, maxvals = regression_preds, np.ones((N, K, 1), dtype=np.float32)
+
+    preds = preds * img_size
+
+    # Transform back to the image
+    for i in range(N):
+        preds[i] = transform_preds(preds[i], center[i], scale[i], img_size)
+
+    return preds, maxvals
+
+
 def keypoints_from_heatmaps(heatmaps,
                             center,
                             scale,
