@@ -1,7 +1,9 @@
+from .bottom_up_aic import BottomUpAicDataset
 from .bottom_up_coco import BottomUpCocoDataset
 from .bottom_up_crowdpose import BottomUpCrowdPoseDataset
 from .bottom_up_mhp import BottomUpMhpDataset
 
 __all__ = [
-    'BottomUpCocoDataset', 'BottomUpCrowdPoseDataset', 'BottomUpMhpDataset'
+    'BottomUpCocoDataset', 'BottomUpCrowdPoseDataset', 'BottomUpMhpDataset',
+    'BottomUpAicDataset'
 ]
