@@ -3,6 +3,7 @@ from .topdown_coco_dataset import TopDownCocoDataset
 from .topdown_coco_wholebody_dataset import TopDownCocoWholeBodyDataset
 from .topdown_crowdpose_dataset import TopDownCrowdPoseDataset
 from .topdown_jhmdb_dataset import TopDownJhmdbDataset
+from .topdown_mhp_dataset import TopDownMhpDataset
 from .topdown_mpii_dataset import TopDownMpiiDataset
 from .topdown_mpii_trb_dataset import TopDownMpiiTrbDataset
 from .topdown_ochuman_dataset import TopDownOCHumanDataset
@@ -11,5 +12,6 @@ from .topdown_posetrack18_dataset import TopDownPoseTrack18Dataset
 __all__ = [
     'TopDownAicDataset', 'TopDownCocoDataset', 'TopDownCocoWholeBodyDataset',
     'TopDownCrowdPoseDataset', 'TopDownMpiiDataset', 'TopDownMpiiTrbDataset',
-    'TopDownOCHumanDataset', 'TopDownPoseTrack18Dataset', 'TopDownJhmdbDataset'
+    'TopDownOCHumanDataset', 'TopDownPoseTrack18Dataset',
+    'TopDownJhmdbDataset', 'TopDownMhpDataset'
 ]
