@@ -70,6 +70,8 @@ class TopDownMpiiDataset(TopDownBaseDataset):
         self.ann_info['joint_weights'] = np.ones(
             (self.ann_info['num_joints'], 1), dtype=np.float32)
 
+        self.dataset_name = 'mpii'
+
         self.db = self._get_db()
         self.image_set = set(x['image_file'] for x in self.db)
         self.num_images = len(self.image_set)
@@ -93,6 +95,7 @@ class TopDownMpiiDataset(TopDownBaseDataset):
             # Adjust center/scale slightly to avoid cropping limbs
             if center[0] != -1:
                 center[1] = center[1] + 15 * scale[1]
+                # padding to include proper amount of context
                 scale = scale * 1.25
 
             # MPII uses matlab format, index is 1-based,
@@ -121,7 +124,7 @@ class TopDownMpiiDataset(TopDownBaseDataset):
                 'rotation': 0,
                 'joints_3d': joints_3d,
                 'joints_3d_visible': joints_3d_visible,
-                'dataset': 'mpii',
+                'dataset': self.dataset_name,
                 'bbox_score': 1
             })
             bbox_id = bbox_id + 1
@@ -143,11 +146,11 @@ class TopDownMpiiDataset(TopDownBaseDataset):
         Args:
             outputs(list(preds, boxes, image_path, heatmap)):
 
-                * preds(np.ndarray[1,K,3]): The first two dimensions are
+                * preds (np.ndarray[N,K,3]): The first two dimensions are
                   coordinates, score is the third dimension of the array.
-                * boxes(np.ndarray[1,6]): [center[0], center[1], scale[0]
+                * boxes (np.ndarray[N,6]): [center[0], center[1], scale[0]
                   , scale[1],area, score]
-                * image_path(list[str]): For example, ['/val2017/000000
+                * image_paths (list[str]): For example, ['/val2017/000000
                   397133.jpg']
                 * heatmap (np.ndarray[N, K, H, W]): model output heatmap.
 
@@ -166,7 +169,9 @@ class TopDownMpiiDataset(TopDownBaseDataset):
                 raise KeyError(f'metric {metric} is not supported')
 
         kpts = []
-        for preds, _, _, _, bbox_ids in outputs:
+        for output in outputs:
+            preds = output['preds']
+            bbox_ids = output['bbox_ids']
             batch_size = len(bbox_ids)
             for i in range(batch_size):
                 kpts.append({'keypoints': preds[i], 'bbox_id': bbox_ids[i]})
