@@ -111,11 +111,14 @@ class Collect:
     another dict with keys 'filename', 'label', 'original_shape'.
 
     Args:
-        keys (Sequence[str]): Required keys to be collected.
+        keys (Sequence[str|tuple]): Required keys to be collected. If a tuple
+          (key, key_new) is given as an element, the item retrived by key will
+          be renamed as key_new in collected data.
         meta_name (str): The name of the key that contains meta infomation.
           This key is always populated. Default: "img_metas".
-        meta_keys (Sequence[str]): Keys that are collected under meta_name.
-          The contents of the `meta_name` dictionary depends on `meta_keys`.
+        meta_keys (Sequence[str|tuple]): Keys that are collected under
+          meta_name. The contents of the `meta_name` dictionary depends
+          on `meta_keys`.
     """
 
     def __init__(self, keys, meta_keys, meta_name='img_metas'):
@@ -135,12 +138,22 @@ class Collect:
 
         data = {}
         for key in self.keys:
-            data[key] = results[key]
+            if isinstance(key, tuple):
+                assert len(key) == 2
+                key_src, key_tgt = key[:2]
+            else:
+                key_src = key_tgt = key
+            data[key_tgt] = results[key_src]
 
         meta = {}
         if len(self.meta_keys) != 0:
             for key in self.meta_keys:
-                meta[key] = results[key]
+                if isinstance(key, tuple):
+                    assert len(key) == 2
+                    key_src, key_tgt = key[:2]
+                else:
+                    key_src = key_tgt = key
+                meta[key_tgt] = results[key_src]
         if 'bbox_id' in results:
             meta['bbox_id'] = results['bbox_id']
         data[self.meta_name] = DC(meta, cpu_only=True)
@@ -188,19 +201,6 @@ class Albumentation:
     """
 
     def __init__(self, transforms, keymap=None):
-        self.allowed_transforms = [
-            'Blur', 'CLAHE', 'ChannelDropout', 'ChannelShuffle', 'ColorJitter',
-            'Downscale', 'Emboss', 'Equalize', 'FDA', 'FancyPCA', 'FromFloat',
-            'GaussNoise', 'GaussianBlur', 'GlassBlur', 'HistogramMatching',
-            'HueSaturationValue', 'IAAAdditiveGaussianNoise', 'IAAEmboss',
-            'IAASharpen', 'IAASuperpixels', 'ISONoise', 'ImageCompression',
-            'InvertImg', 'MedianBlur', 'MotionBlur', 'MultiplicativeNoise',
-            'Normalize', 'Posterize', 'RGBShift', 'RandomBrightnessContrast',
-            'RandomFog', 'RandomGamma', 'RandomRain', 'RandomShadow',
-            'RandomSnow', 'RandomSunFlare', 'Sharpen', 'Solarize', 'ToFloat',
-            'ToGray', 'ToSepia'
-        ]
-
         if albumentations is None:
             raise RuntimeError('albumentations is not installed')
 
@@ -235,9 +235,9 @@ class Albumentation:
         if mmcv.is_str(obj_type):
             if albumentations is None:
                 raise RuntimeError('albumentations is not installed')
-            if obj_type not in self.allowed_transforms:
-                warnings.warn(
-                    '{obj_type} is not supported. Please use with caution.')
+            if not hasattr(albumentations.augmentations.transforms, obj_type):
+                warnings.warn('{obj_type} is not pixel-level transformations. '
+                              'Please use with caution.')
             obj_cls = getattr(albumentations, obj_type)
         else:
             raise TypeError(f'type must be a str, but got {type(obj_type)}')
