@@ -1,5 +1,6 @@
 from .bottom_up import BottomUp
 from .mesh import ParametricMesh
+from .multi_task import MultiTask
 from .top_down import TopDown
 
-__all__ = ['TopDown', 'BottomUp', 'ParametricMesh']
+__all__ = ['TopDown', 'BottomUp', 'ParametricMesh', 'MultiTask']
